==> apache-camel-3.0.0-src.zip: apache-camel-3.0.0/components/camel-aws-mq/src/main/java/org/apache/camel/component/aws/mq/MQComponent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws.mq;

import java.util.Map;
import java.util.Set;

import com.amazonaws.services.mq.AmazonMQ;
import org.apache.camel.CamelContext;
import org.apache.camel.Endpoint;
import org.apache.camel.spi.Metadata;
import org.apache.camel.spi.annotations.Component;
import org.apache.camel.support.DefaultComponent;
import org.apache.camel.util.ObjectHelper;

/**
 * For working with Amazon MQ.
 */
@Component("aws-mq")
public class MQComponent extends DefaultComponent {

    @Metadata
    private String accessKey;
    @Metadata
    private String secretKey;
    @Metadata
    private String region;
    @Metadata(label = "advanced")    
    private MQConfiguration configuration;
    
    public MQComponent() {
        this(null);
    }
    
    public MQComponent(CamelContext context) {
        super(context);
        
        this.configuration = new MQConfiguration();
        registerExtension(new MQComponentVerifierExtension());
    }

    @Override
    protected Endpoint createEndpoint(String uri, String remaining, Map<String, Object> parameters) throws Exception {
        MQConfiguration configuration = this.configuration.copy();
        setProperties(configuration, parameters);

        if (ObjectHelper.isEmpty(configuration.getAccessKey())) {
            setAccessKey(accessKey);
        }
        if (ObjectHelper.isEmpty(configuration.getSecretKey())) {
            setSecretKey(secretKey);
        }
        if (ObjectHelper.isEmpty(configuration.getRegion())) {
            setRegion(region);
        }
        checkAndSetRegistryClient(configuration);
        if (configuration.getAmazonMqClient() == null && (configuration.getAccessKey() == null || configuration.getSecretKey() == null)) {
            throw new IllegalArgumentException("amazonMQClient or accessKey and secretKey must be specified");
        }
        
        MQEndpoint endpoint = new MQEndpoint(uri, this, configuration);
        return endpoint;
    }
    
    public MQConfiguration getConfiguration() {
        return configuration;
    }

    /**
     * The AWS MQ default configuration
     */
    public void setConfiguration(MQConfiguration configuration) {
        this.configuration = configuration;
    }

    public String getAccessKey() {
        return configuration.getAccessKey();
    }

    /**
     * Amazon AWS Access Key
     */
    public void setAccessKey(String accessKey) {
        configuration.setAccessKey(accessKey);
    }

    public String getSecretKey() {
        return configuration.getSecretKey();
    }

    /**
     * Amazon AWS Secret Key
     */
    public void setSecretKey(String secretKey) {
        configuration.setSecretKey(secretKey);
    }
    
    public String getRegion() {
        return configuration.getRegion();
    }

    /**
     * The region in which MQ client needs to work
     */
    public void setRegion(String region) {
        configuration.setRegion(region);
    }

    private void checkAndSetRegistryClient(MQConfiguration configuration) {
        Set<AmazonMQ> clients = getCamelContext().getRegistry().findByType(AmazonMQ.class);
        if (clients.size() == 1) {
            configuration.setAmazonMqClient(clients.stream().findFirst().get());
        }
    }
}

==> apache-camel-3.4.5-src.zip: apache-camel-3.4.5/components/camel-aws-mq/src/main/java/org/apache/camel/component/aws/mq/MQComponent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws.mq;

import java.util.Map;
import java.util.Set;

import com.amazonaws.services.mq.AmazonMQ;
import org.apache.camel.CamelContext;
import org.apache.camel.Endpoint;
import org.apache.camel.spi.Metadata;
import org.apache.camel.spi.annotations.Component;
import org.apache.camel.support.DefaultComponent;

/**
 * For working with Amazon MQ.
 */
@Component("aws-mq")
public class MQComponent extends DefaultComponent {

    @Metadata  
    private MQConfiguration configuration = new MQConfiguration();
    
    public MQComponent() {
        this(null);
    }
    
    public MQComponent(CamelContext context) {
        super(context);
        
        registerExtension(new MQComponentVerifierExtension());
    }

    @Override
    protected Endpoint createEndpoint(String uri, String remaining, Map<String, Object> parameters) throws Exception {
        MQConfiguration configuration = this.configuration != null ? this.configuration.copy() : new MQConfiguration();
        MQEndpoint endpoint = new MQEndpoint(uri, this, configuration);
        setProperties(endpoint, parameters);
        checkAndSetRegistryClient(configuration);
        if (configuration.getAmazonMqClient() == null && (configuration.getAccessKey() == null || configuration.getSecretKey() == null)) {
            throw new IllegalArgumentException("amazonMQClient or accessKey and secretKey must be specified");
        }
        
        return endpoint;
    }
    
    public MQConfiguration getConfiguration() {
        return configuration;
    }

    /**
     * The Component configuration
     */
    public void setConfiguration(MQConfiguration configuration) {
        this.configuration = configuration;
    }

    private void checkAndSetRegistryClient(MQConfiguration configuration) {
        Set<AmazonMQ> clients = getCamelContext().getRegistry().findByType(AmazonMQ.class);
        if (clients.size() == 1) {
            configuration.setAmazonMqClient(clients.stream().findFirst().get());
        }
    }
}
